# `py-normalise-email`

Python port of the
[`normalizeEmail.js`](https://github.com/validatorjs/validator.js/blob/master/src/lib/normalizeEmail.js)
component of [`validator.js`](https://github.com/validatorjs/validator.js).
